// This file was automatically generated by bifcl from /pobj/zeek-8.2.0/zeek-8.2.0/src/analyzer/analyzer.bif (alternative mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_0_build_i386_src_analyzer_analyzer_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_0_build_i386_src_analyzer_analyzer_bif
#define _pobj_zeek_8_2_0_build_i386_src_analyzer_analyzer_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifFunc::Analyzer { extern zeek::ValPtr __enable_analyzer_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc::Analyzer { extern zeek::ValPtr __disable_analyzer_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc::Analyzer { extern zeek::ValPtr __disable_all_analyzers_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc::Analyzer { extern zeek::ValPtr __register_for_port_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc::Analyzer { extern zeek::ValPtr __schedule_analyzer_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc::Analyzer { extern zeek::ValPtr __name_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc::Analyzer { extern zeek::ValPtr __tag_bif(zeek::detail::Frame* frame, const zeek::Args*); }
namespace zeek::BifFunc::Analyzer { extern zeek::ValPtr __has_tag_bif(zeek::detail::Frame* frame, const zeek::Args*); }

#endif
