// This file was automatically generated by bifcl from /pobj/zeek-8.2.0/zeek-8.2.0/src/analyzer/protocol/ftp/events.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_0_build_i386_src_analyzer_protocol_ftp_events_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_0_build_i386_src_analyzer_protocol_ftp_events_bif
#define _pobj_zeek_8_2_0_build_i386_src_analyzer_protocol_ftp_events_bif
#include "zeek/zeek-bif.h"
#endif
#endif

extern zeek::EventHandlerPtr ftp_request; 
namespace zeek::BifEvent { void enqueue_ftp_request(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek::IntrusivePtr<zeek::StringVal> command, zeek::IntrusivePtr<zeek::StringVal> arg);  }
extern zeek::EventHandlerPtr ftp_reply; 
namespace zeek::BifEvent { void enqueue_ftp_reply(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek_uint_t code, zeek::IntrusivePtr<zeek::StringVal> msg, int cont_resp);  }
extern zeek::EventHandlerPtr ftp_starttls; 
namespace zeek::BifEvent { void enqueue_ftp_starttls(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c);  }

#endif
