// This file was automatically generated by bifcl from /pobj/zeek-8.2.0/zeek-8.2.0/src/input/readers/binary/binary.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_0_build_i386_src_input_readers_binary_binary_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_0_build_i386_src_input_readers_binary_binary_bif
#define _pobj_zeek_8_2_0_build_i386_src_input_readers_binary_binary_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifConst::InputBinary { extern zeek_uint_t chunk_size; }
namespace zeek::BifConst::InputBinary { extern zeek::IntrusivePtr<zeek::StringVal> path_prefix; }

#endif
