// This file was automatically generated by bifcl from /pobj/zeek-8.2.0/zeek-8.2.0/src/analyzer/protocol/pop3/consts.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_0_build_i386_src_analyzer_protocol_pop3_consts_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_0_build_i386_src_analyzer_protocol_pop3_consts_bif
#define _pobj_zeek_8_2_0_build_i386_src_analyzer_protocol_pop3_consts_bif
#include "zeek/zeek-bif.h"
#endif
#endif

namespace zeek::BifConst::POP3 { extern zeek_uint_t max_pending_commands; }
namespace zeek::BifConst::POP3 { extern zeek_uint_t max_unknown_client_commands; }

#endif
