// This file was automatically generated by bifcl from /pobj/zeek-8.2.0/zeek-8.2.0/src/analyzer/protocol/smtp/events.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_0_build_i386_src_analyzer_protocol_smtp_events_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_0_build_i386_src_analyzer_protocol_smtp_events_bif
#define _pobj_zeek_8_2_0_build_i386_src_analyzer_protocol_smtp_events_bif
#include "zeek/zeek-bif.h"
#endif
#endif

extern zeek::EventHandlerPtr smtp_request; 
namespace zeek::BifEvent { void enqueue_smtp_request(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, int is_orig, zeek::IntrusivePtr<zeek::StringVal> command, zeek::IntrusivePtr<zeek::StringVal> arg);  }
extern zeek::EventHandlerPtr smtp_reply; 
namespace zeek::BifEvent { void enqueue_smtp_reply(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, int is_orig, zeek_uint_t code, zeek::IntrusivePtr<zeek::StringVal> cmd, zeek::IntrusivePtr<zeek::StringVal> msg, int cont_resp);  }
extern zeek::EventHandlerPtr smtp_data; 
namespace zeek::BifEvent { void enqueue_smtp_data(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, int is_orig, zeek::IntrusivePtr<zeek::StringVal> data);  }
extern zeek::EventHandlerPtr smtp_unexpected; 
namespace zeek::BifEvent { void enqueue_smtp_unexpected(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, int is_orig, zeek::IntrusivePtr<zeek::StringVal> msg, zeek::IntrusivePtr<zeek::StringVal> detail);  }
extern zeek::EventHandlerPtr smtp_starttls; 
namespace zeek::BifEvent { void enqueue_smtp_starttls(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c);  }

#endif
