// This file was automatically generated by bifcl from /pobj/zeek-8.2.0/zeek-8.2.0/src/analyzer/protocol/smb/smb1_com_create_directory.bif (plugin mode).

#pragma once

#if defined(ZEEK_IN_NETVAR) || ! defined(_pobj_zeek_8_2_0_build_i386_src_analyzer_protocol_smb_smb1_com_create_directory_bif)
#ifndef ZEEK_IN_NETVAR
#ifndef _pobj_zeek_8_2_0_build_i386_src_analyzer_protocol_smb_smb1_com_create_directory_bif
#define _pobj_zeek_8_2_0_build_i386_src_analyzer_protocol_smb_smb1_com_create_directory_bif
#include "zeek/zeek-bif.h"
#endif
#endif

extern zeek::EventHandlerPtr smb1_create_directory_request; 
namespace zeek::BifEvent { void enqueue_smb1_create_directory_request(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek::IntrusivePtr<zeek::Val> hdr, zeek::IntrusivePtr<zeek::StringVal> directory_name);  }
extern zeek::EventHandlerPtr smb1_create_directory_response; 
namespace zeek::BifEvent { void enqueue_smb1_create_directory_response(zeek::analyzer::Analyzer* analyzer, zeek::Connection* c, zeek::IntrusivePtr<zeek::Val> hdr);  }

#endif
